==> lxqt-config_0.14.1.orig.tar.xz: lxqt-config-0.14.1/lxqt-config-file-associations/translations/lxqt-config-file-associations_nb_NO.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb_NO">
<context>
    <name>ApplicationChooser</name>
    <message>
        <location filename="../applicationchooser.ui" line="14"/>
        <source>ApplicationChooser</source>
        <translation>Programvelger</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="46"/>
        <source>Pick an application for:</source>
        <translation>Velg et program for:</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="110"/>
        <source>1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="115"/>
        <source>Applications that handle JPEG</source>
        <translation>Program for å håndtere JPEG</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="124"/>
        <location filename="../applicationchooser.ui" line="129"/>
        <location filename="../applicationchooser.ui" line="139"/>
        <location filename="../applicationchooser.ui" line="144"/>
        <source>New Subitem</source>
        <translation>Nytt undernivå</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="135"/>
        <location filename="../applicationchooser.cpp" line="113"/>
        <source>Other applications</source>
        <translation>Andre programmer</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="114"/>
        <source>Applications that handle %1</source>
        <translation>Programmer som håndterer %1</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="151"/>
        <source>No applications found</source>
        <translation>Ingen programmer funnet</translation>
    </message>
</context>
<context>
    <name>MimetypeViewer</name>
    <message>
        <location filename="../mimetypeviewer.cpp" line="156"/>
        <location filename="../mimetypeviewer.cpp" line="207"/>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="203"/>
        <source>&amp;Change...</source>
        <translation>&amp;Forandr..</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="208"/>
        <source>&amp;Choose...</source>
        <translation>&amp;Velg...</translation>
    </message>
</context>
<context>
    <name>mimetypeviewer</name>
    <message>
        <location filename="../mimetypeviewer.ui" line="20"/>
        <source>File Associations</source>
        <translation>Filassosiasjoner</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="56"/>
        <source>Default application</source>
        <translation>Standardprogram</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="68"/>
        <source>&amp;Choose...</source>
        <translation>&amp;Velg...</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="117"/>
        <source>TextLabel</source>
        <translation>Tekstmerkelapp</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="124"/>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="144"/>
        <source>Patterns</source>
        <translation>Mønstre</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="156"/>
        <source>*.txt *.xml</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="173"/>
        <source>MIME type</source>
        <translation>MIME-type</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="191"/>
        <source>Icon</source>
        <translation>Symbol</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="198"/>
        <source>Description</source>
        <translation>Beskrivelse</translation>
    </message>
</context>
</TS>

==> lxqt-config_0.15.0.orig.tar.xz: lxqt-config-0.15.0/lxqt-config-file-associations/translations/lxqt-config-file-associations_nb_NO.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb_NO">
<context>
    <name>ApplicationChooser</name>
    <message>
        <location filename="../applicationchooser.ui" line="14"/>
        <source>ApplicationChooser</source>
        <translation>Programvelger</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="46"/>
        <source>Pick an application for:</source>
        <translation>Velg et program for:</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="110"/>
        <source>1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="115"/>
        <source>Applications that handle JPEG</source>
        <translation>Program for å håndtere JPEG</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="124"/>
        <location filename="../applicationchooser.ui" line="129"/>
        <location filename="../applicationchooser.ui" line="139"/>
        <location filename="../applicationchooser.ui" line="144"/>
        <source>New Subitem</source>
        <translation>Nytt undernivå</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="135"/>
        <location filename="../applicationchooser.cpp" line="113"/>
        <source>Other applications</source>
        <translation>Andre programmer</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="114"/>
        <source>Applications that handle %1</source>
        <translation>Programmer som håndterer %1</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="151"/>
        <source>No applications found</source>
        <translation>Ingen programmer funnet</translation>
    </message>
</context>
<context>
    <name>MimetypeViewer</name>
    <message>
        <location filename="../mimetypeviewer.cpp" line="156"/>
        <location filename="../mimetypeviewer.cpp" line="207"/>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="203"/>
        <source>&amp;Change...</source>
        <translation>&amp;Endre...</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="208"/>
        <source>&amp;Choose...</source>
        <translation>&amp;Velg...</translation>
    </message>
</context>
<context>
    <name>mimetypeviewer</name>
    <message>
        <location filename="../mimetypeviewer.ui" line="20"/>
        <source>File Associations</source>
        <translation>Filtilknytninger</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="56"/>
        <source>Default application</source>
        <translation>Standardprogram</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="68"/>
        <source>&amp;Choose...</source>
        <translation>&amp;Velg...</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="117"/>
        <source>TextLabel</source>
        <translation>Tekstetikett</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="124"/>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="144"/>
        <source>Patterns</source>
        <translation>Mønstre</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="156"/>
        <source>*.txt *.xml</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="173"/>
        <source>MIME type</source>
        <translation>MIME-type</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="191"/>
        <source>Icon</source>
        <translation>Symbol</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="198"/>
        <source>Description</source>
        <translation>Beskrivelse</translation>
    </message>
</context>
</TS>
